[PolicyKit-gnome] Use avatar-default instead of stock_person



commit 715208ef9f706f7b06ef3f1c2902e2a65247c5da
Author: Matthias Clasen <mclasen redhat com>
Date:   Wed Feb 9 19:53:55 2011 -0500

    Use avatar-default instead of stock_person
    
    The former is a standard icon name, the latter doesn't exist
    in the icon theme anymore.

 src/polkitgnomeauthenticationdialog.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/src/polkitgnomeauthenticationdialog.c b/src/polkitgnomeauthenticationdialog.c
index 1473d22..1abf984 100644
--- a/src/polkitgnomeauthenticationdialog.c
+++ b/src/polkitgnomeauthenticationdialog.c
@@ -207,11 +207,11 @@ create_user_combobox (PolkitGnomeAuthenticationDialog *dialog)
           g_free (path);
         }
 
       /* fall back to stock_person icon */
       if (pixbuf == NULL)
         {
           pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
-                                             "stock_person",
+                                             "avatar-default",
                                              GTK_ICON_SIZE_MENU,
                                              0,
                                              NULL);
@@ -207,11 +207,11 @@ create_user_combobox (PolkitGnomeAuthenticationDialog *dialog)
         }
 
-      /* fall back to stock_person icon */
+      /* fall back to avatar-default icon */
       if (pixbuf == NULL)
         {



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]